@@ -1,5 +1,7 @@
 from json import encoder
 from flask import Flask, request
+from flask.helpers import make_response, send_file
+from flask.wrappers import Response
 from flask_cors import CORS  # , cross_origin
 import json
 from .ledger_exec import LedgerExecutor
@@ -15,13 +17,40 @@ def hello():
     return "Hello World!"
 
 
+@app.route('/hello')
+def hello_img():
+    # Returns an image, can be used with <img> element to check online status
+
+    import io
+    import base64
+    from werkzeug.wsgi import FileWrapper
+    from flask import Response
+
+    # Base64 encoded pixel
+    pixelEncoded = b'iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAADUlEQVR42mNk+M9QDwADhgGAWjR9awAAAABJRU5ErkJggg=='
+    pixel = base64.b64decode(pixelEncoded)
+    buf = io.BytesIO(pixel)
+    
+    #response = make_response(buf)
+    wrapper = FileWrapper(buf)
+    response = Response(wrapper, mimetype='image/png', direct_passthrough=True)
+    
+    return response
+    #return send_file(buf, attachment_filename='hello.png', mimetype='image/png')
+
+
 @app.route("/accounts")
 def accounts():
     params = "accounts"
     ledger = LedgerExecutor(app.logger)
     result = ledger.run(params)
 
-    return result
+    lines = result.split('\n')
+    # clean-up blank lines
+    clean_lines = [x for x in lines if x]
+    output = json.dumps(clean_lines)
+
+    return output
 
 
 @app.route("/balance")
